@@ -10,11 +10,11 @@ Net::SNMP::Mixin - mixin framework for Net::SNMP
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 ABSTRACT
 
@@ -54,7 +54,7 @@ use Sub::Exporter -setup => {
 
 # needed for housekeeping of already mixed in modules
 # in order to find double mixins
-our %register_class_mixins;
+my %register_class_mixins;
 
 =head1 SYNOPSIS
 
@@ -142,13 +142,22 @@ sub mixer {
   return $self;
 }
 
+#
+# Mix the module into Net::SNMP with the help of Sub::Exporter.
+#
 sub _class_mixer {
   my ( $class, $mixin ) = @_;
 
   eval "use $mixin {into => 'Net::SNMP'}";
   Carp::croak $@ if $@;
+  return;
 }
 
+#
+# Create a new package as a subclass of Net::SNMP
+# Rebless $session in the new package.
+# Mix the module into the new package with the help of Sub::Exporter.
+#
 sub _obj_mixer {
   my ( $session, $mixin )      = @_;
   my ( $package, $pkg_reaper ) = _make_package($session);
@@ -162,13 +171,13 @@ sub _obj_mixer {
 
   eval "use $mixin {into => '$package'}";
   Carp::croak $@ if $@;
+  return;
 }
 
 #
-# make unique mixin subclass for this session with name
-# Net::SNMP::<refaddr $session> und make it a subclass
-# of Net::SNMP. Mix all mixin modules into this only package
-# for this session.
+# Make unique mixin subclass for this session with name.
+# Net::SNMP::<refaddr $session> und make it a subclass of Net::SNMP.
+# Arm a package reaper, see perldoc Package::Reaper.
 #
 sub _make_package {
   my $session  = shift;
@@ -215,9 +224,10 @@ sub init_mixins {
   Carp::croak "pure instance method called as class method,"
     unless ref $session;
 
-  my @class_mixins    = _get_class_mixins();
-  my @instance_mixins = _get_instance_mixins($session);
-  my @all_mixins      = (@class_mixins, @instance_mixins);
+  my @class_mixins    = keys %register_class_mixins;
+  my @instance_mixins = keys %{ $session->{$prefix}{mixins} };
+
+  my @all_mixins = ( @class_mixins, @instance_mixins );
 
   unless ( scalar @all_mixins ) {
     Carp::carp "please use first the mixer() method, nothing to init\n";
@@ -228,29 +238,11 @@ sub init_mixins {
   foreach my $mixin (@all_mixins) {
 
     # call the _init() method in module $mixin
-    eval "\$session->${mixin}::_init(\$reload)";
+    my $mixin_init = $mixin . '::_init';
+    eval { $session->$mixin_init($reload) };
+
     Carp::croak $@ if $@;
   }
-}
-
-#
-# _get_class_mixins()
-# Returns a list of already mixed-in modules into the Net::SNMP class.
-#
-sub _get_class_mixins {
-    return keys %register_class_mixins;
-}
-
-#
-# $session->_get_instance_mixins() >>
-# Returns a list of already mixed-in modules into the namespace of $session.
-#
-sub _get_instance_mixins {
-  my $session = shift;
-
-  return keys %{ $session->{$prefix}{mixins} }
-    if defined $session->{$prefix}{mixins};
-
   return;
 }
 
@@ -276,7 +268,7 @@ In no circumstance change the given attributes of the calling Net::SNMP session
 
 =item *
 
-Don't assume the translation of the SNMP values by default. Due to the asynchronous nature of the SNMP calls, you can't rely on the output of $session->translate. If you need a special representation of a value, you have to check the values itself and perhaps translate or untranslate it when needed. See the source of Net::SNMP::Mixin::Dot1qVlan for an example.
+Don't assume the translation of the SNMP values by default. Due to the asynchronous nature of the SNMP calls, you can't rely on the output of $session->translate. If you need a special representation of a value, you have to check the values itself and perhaps translate or untranslate it when needed. See the source of Net::SNMP::Mixin::Dot1qVlanStatic for an example.
 
 =item *
 
